FromMessagePack

Trait FromMessagePack 

pub trait FromMessagePack<'a>
where Self: Sized,
{ // Required method fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>; }
A data structure that can be deserialized from MessagePack format.

Required Methods

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>

Reads the MessagePack representation of this value from the provided reader.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<'a> FromMessagePack<'a> for &'a str

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for &'a [u8]

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for Cow<'a, str>

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for Cow<'a, [u8]>

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for bool

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for char

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for f32

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for f64

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for i8

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for i16

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for i32

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for i64

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for isize

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for u8

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for u16

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for u32

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for u64

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for ()

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for usize

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a> FromMessagePack<'a> for String

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, K: Ord + FromMessagePack<'a>, V: FromMessagePack<'a>> FromMessagePack<'a> for BTreeMap<K, V>

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, K: Hash + Eq + FromMessagePack<'a>, V: FromMessagePack<'a>> FromMessagePack<'a> for HashMap<K, V>

Available on crate feature std only.
Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T0: FromMessagePack<'a>, T1: FromMessagePack<'a>> FromMessagePack<'a> for (T0, T1)

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T0: FromMessagePack<'a>, T1: FromMessagePack<'a>, T2: FromMessagePack<'a>> FromMessagePack<'a> for (T0, T1, T2)

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T0: FromMessagePack<'a>, T1: FromMessagePack<'a>, T2: FromMessagePack<'a>, T3: FromMessagePack<'a>> FromMessagePack<'a> for (T0, T1, T2, T3)

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T0: FromMessagePack<'a>, T1: FromMessagePack<'a>, T2: FromMessagePack<'a>, T3: FromMessagePack<'a>, T4: FromMessagePack<'a>> FromMessagePack<'a> for (T0, T1, T2, T3, T4)

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T0: FromMessagePack<'a>, T1: FromMessagePack<'a>, T2: FromMessagePack<'a>, T3: FromMessagePack<'a>, T4: FromMessagePack<'a>, T5: FromMessagePack<'a>> FromMessagePack<'a> for (T0, T1, T2, T3, T4, T5)

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T0: FromMessagePack<'a>, T1: FromMessagePack<'a>, T2: FromMessagePack<'a>, T3: FromMessagePack<'a>, T4: FromMessagePack<'a>, T5: FromMessagePack<'a>, T6: FromMessagePack<'a>> FromMessagePack<'a> for (T0, T1, T2, T3, T4, T5, T6)

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T0: FromMessagePack<'a>, T1: FromMessagePack<'a>, T2: FromMessagePack<'a>, T3: FromMessagePack<'a>, T4: FromMessagePack<'a>, T5: FromMessagePack<'a>, T6: FromMessagePack<'a>, T7: FromMessagePack<'a>> FromMessagePack<'a> for (T0, T1, T2, T3, T4, T5, T6, T7)

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T0: FromMessagePack<'a>, T1: FromMessagePack<'a>, T2: FromMessagePack<'a>, T3: FromMessagePack<'a>, T4: FromMessagePack<'a>, T5: FromMessagePack<'a>, T6: FromMessagePack<'a>, T7: FromMessagePack<'a>, T8: FromMessagePack<'a>> FromMessagePack<'a> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T0: FromMessagePack<'a>, T1: FromMessagePack<'a>, T2: FromMessagePack<'a>, T3: FromMessagePack<'a>, T4: FromMessagePack<'a>, T5: FromMessagePack<'a>, T6: FromMessagePack<'a>, T7: FromMessagePack<'a>, T8: FromMessagePack<'a>, T9: FromMessagePack<'a>> FromMessagePack<'a> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T0: FromMessagePack<'a>, T1: FromMessagePack<'a>, T2: FromMessagePack<'a>, T3: FromMessagePack<'a>, T4: FromMessagePack<'a>, T5: FromMessagePack<'a>, T6: FromMessagePack<'a>, T7: FromMessagePack<'a>, T8: FromMessagePack<'a>, T9: FromMessagePack<'a>, T10: FromMessagePack<'a>> FromMessagePack<'a> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T0: FromMessagePack<'a>, T1: FromMessagePack<'a>, T2: FromMessagePack<'a>, T3: FromMessagePack<'a>, T4: FromMessagePack<'a>, T5: FromMessagePack<'a>, T6: FromMessagePack<'a>, T7: FromMessagePack<'a>, T8: FromMessagePack<'a>, T9: FromMessagePack<'a>, T10: FromMessagePack<'a>, T11: FromMessagePack<'a>> FromMessagePack<'a> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T> FromMessagePack<'a> for PhantomData<T>

Source

fn read<R: Read<'a>>(_: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T: Ord + FromMessagePack<'a>> FromMessagePack<'a> for BTreeSet<T>

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T: Hash + Eq + FromMessagePack<'a>> FromMessagePack<'a> for HashSet<T>

Available on crate feature std only.
Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T: FromMessagePack<'a> + Ord> FromMessagePack<'a> for BinaryHeap<T>

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T: FromMessagePack<'a>> FromMessagePack<'a> for Option<T>

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T: FromMessagePack<'a>> FromMessagePack<'a> for Box<T>

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T: FromMessagePack<'a>> FromMessagePack<'a> for LinkedList<T>

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T: FromMessagePack<'a>> FromMessagePack<'a> for VecDeque<T>

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T: FromMessagePack<'a>> FromMessagePack<'a> for Rc<T>

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T: FromMessagePack<'a>> FromMessagePack<'a> for Arc<T>

Available on crate feature std only.
Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T: FromMessagePack<'a>> FromMessagePack<'a> for Vec<T>

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, T: FromMessagePack<'a>, E: FromMessagePack<'a>> FromMessagePack<'a> for Result<T, E>

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>
where Self: Sized,

Source

impl<'a, const N: usize> FromMessagePack<'a> for &'a [u8; N]

Source

fn read<R: Read<'a>>(reader: &mut R) -> Result<Self>

Implementors